Evolution Strategies (ES)
=========================

.. autoclass:: pypop7.optimizers.es.es.ES



.. toctree::
   :maxdepth: 2
   :caption: ESs:

   lmmaes
   r1es
   lmcma
   lmcmaes
   fmaes
   maes
   sepcmaes
   saes
   csaes
   dsaes
   ssaes
   res
